#include "DxLib.h"
#include "Player.h"
#include "Keyboard.h"

int WINAPI WinMain(HINSTANCE,HINSTANCE,LPSTR,int){
	ChangeWindowMode(TRUE),DxLib_Init(),SetDrawScreen( DX_SCREEN_BACK );

	Player_t Player1, Player2;
	Player_Initialize( &Player1,   0 );// 初期化
	Player_Initialize( &Player2, 200 );// 初期化

	while( ScreenFlip()==0 && ProcessMessage()==0 && ClearDrawScreen()==0 ){

		Keyboard_Update();

		Player_Update( &Player1 );	// 計算
		Player_Update( &Player2 );	// 計算

		Player_Draw( Player1 );	// 描画
		Player_Draw( Player2 );	// 描画

	}

	Player_Finalize( Player1 );  // 終了処理
	Player_Finalize( Player2 );  // 終了処理

	DxLib_End();
	return 0;
}
